*************************
* Introduction to Stata
* September 16, 2014
* StatLab@UVa Library
* Michele Claibourn
*************************

* use Ctrl+D to submit commands or click the Execute button;
* green text preceded with asterisks are comments.

*************************
* STARTING THE DO FILE

* Stata periodically releases new versions, which means do-files written for 
* older versions might stop working.
* To prevent that from happening, specify the version of Stata that you are 
* using at the top of do-files:

version 13.0

* Set working directory (where Stata looks for files to open and puts files to be saved); 
* Or do File...Change Working Directory. 
* You'll have to change this line to your own directory:
cd "J:\public_html\IntroStata\"

* Close any open log file; capture supresses error generated if no log is open 
capture log close 

* Start a log
log using "introStata.log", replace  /*text log*/
*log using "introStata", replace /* scml, Stata Markup and Control Language */ 

* Or add to previously created log 
*log using "introStata.log", append 

*************************
* READING AND SAVING DATA

* Data in Stata format: use (if file name contains spaces, it must be in quotes)
use "collegeCompletion.dta", clear  /* clear removes data currently in memory;
									Stata only allows one dataset at a time to be open */

* Data in comma- or tab-delimited format (e.g., an excel spreadsheet): import deliminted
/* 1. The first line should have variable names (32 characters or less; spaces, special characters will be removed,
	except the underscore [_]; the second line begins the data.
   2. No blank rows or columns between data.
   3. Missing numeric data should be coded as an empty cell, not a space, dot, or any other non-numeric data. 
	Often, 0, 9, or 99 is used to code missing numeric data; fine as long as these are not also valid values.
   4. Commas in numbers or text are problematic, Stata thinks they are a delimiter and won't read the data properly. 
	You must remove the commas from numeric values before saving the file.
   5. The file must be saved a a comma-separated file or tab-delimited file in Excel */

import delimited "collegeCompletion.txt", varnames(1) clear
* varnames(1) means "variable names in first row"
* or to read from a url:
import delimited "http://people.virginia.edu/~mpc8t/IntroStata/collegeCompletion.txt", varnames(1) clear

* for Stata 12, use: insheet using collegeCompletion.txt, names clear

* Save imported data as Stata data file with .dta extension
save "collegeCompletion.dta", replace
* use "replace" option to overwrite existing file

* To clear data
clear

* Read in Stata data with the use command
use collegeCompletion, clear

*************************
* DATA MANAGEMENT

*Examining data
describe 
browse

* can also enter/edit data in by hand using data editor (not recommended)
* Note: dot(.) means missing; can be thought of as a really large number

*Look at data in results window: list
list chronname state // list selected variables
* use Enter to advance one line at a time; 
* use spacebar to advance one page at a time;
* use q to quit

list chronname state level control in 1/10 // list selected variables for observations 1 to 10

*Subset data by the 'if' qualifier
list chronname state level control if flagship=="X"
list chronname state control if grad_100_value==0 & level=="4-year"
*You can use any combination of relational and logical operators

/* How many institutions in Virginial have an on-time graduation rate of 0; 
 how many are public/private, 2-year/4-year */

 
*Looking at means, standard deviations, min and max values: summarize
summ grad_150_value
summ grad_150_value grad_100_value student_count fte_value med_sat_value endow_value ft_fac_value
summ endow_value if control=="Public" & level=="4-year" //which public universities have the biggest endowments/student?
list chronname endow_value if contro=="Public" & level=="4-year" & endow_value>100000 & endow_value!=.

*Frequency distributions, appropriate for categorical/ordered variables: tabulate
tab control
tab level
tab1 control level

*Cross-tabs, view the relationship between two categorical/ordered variables: tabulate
tab control level
tab control level, col

*Renaming variables
rename grad_150_value grad150
rename grad_100_value grad100

*Recoding variables
recode grad100 (0/32.9=1) (33.0/66.0=2) (66.1/100=3), into(gradrate100)
recode grad150 (0/32.9=1) (33.0/66.0=2) (66.1/100=3), into(gradrate150)
tab1 gradrate100 gradrate150

*Generating new variables
*As mathematical function of existing variables
gen lnaid=ln(aid_value)
summ aid_value lnaid

*As logical function of existing variables
tab basic
gen research=1 if basic=="Research Universities--high research activity" | /// 
	basic=="Research Universities--very high research activity" | ///
	basic=="Doctoral and Research Universities"
replace research=0 if research==.
tab research

gen flagshipdum=1 if flagship=="X"
replace flagshipdum=0 if flagship==""
tab flagshipdum

* sort data by initial id
sort unitid 
* sort data by on-time graduation
sort exp_award_value
list chronname state level control exp_award_value in 1/10
* sort by Weekday circulation descending and see the first 5
* use gsort to sort descending; add - to variable to indicate descending
gsort -aid_value
list chronname state level control aid_value in 1/10

* generate an ID number
generate id = _n

* use egen for more sophisticated transformations
* egen = "Extensions to GENerate"; see "help egen"
* standardized values of circulation
egen stdaid = std(aid_value)

* Add variable labels
label var grad100 "Percent of first-time, full-time undergrads completing degree on time"
label var research "Carnegie Classification-Research"
describe grad100 research

*Add value labels
label define gradratelbl 1 "Less than 33%" 2 "33-66%" 3 "More than 66%"
label values gradrate100 gradrate150 gradratelbl
tab1 gradrate100 gradrate150

* can label variables and data set
describe
label variable level "2-year or 4-year institution"
label variable control "Public, Private-not for profit, Private-for profit"
label data "College Completion Data obtained from The Chronical of Higher Education"
describe 

* can add notes to data 
notes: This data was downloaded from http://collegecompletion.chronicle.com/
describe
notes

save collegeCompletion_analysis.dta, replace

*************************
* DESCRIPTIVE STATISTICS

* Good practice to separate out the data management script and the analysis script
use collegeCompletion_analysis.dta, replace

* Already seen: tabulate and summarize

* categorical variables (levels)
tab gradrate100
* two-way tables
tab gradrate100 control, col chi2
/*  What's the 150 percent on-time graduation rate among 2-year and 4-year institutions? */


* numeric variables 
summ aid_value
summ grad150, detail
* summarize over subsets
bysort control: summ aid_value

* summarize stores certain values in memory which can be used in calculations
* see stored values
summ aid_value
return list 
display r(mean)
* create variable of centered values for SunSat
gen aid_center = aid_value - r(mean)

* one- and two-way tables of summary statistics
tabulate level, summ(grad100)

/* Do graduation rates vary by private/public control among 4-year, among 2-year institutions? */
bysort level: tab gradrate100 control, col chi2

/* Among 4-year RESEARCH universities, do graduation rates vary by private/public control? */
tab gradrate150 control if research==1, col chi2

* Remove the three private for profit research universities
encode control, gen(controlcat) // Make a version with numbered categories
tab controlcat, nolabel // Verify controlcat is what I expected
list chronname city state level if research==1 & controlcat==1
tab gradrate150 control if research==1 & controlcat!=1, col chi2

* Use the original numeric version of the outcome
oneway grad150 control if research==1, tab bon
oneway grad150 control if research==1 & controlcat!=1, tab bon

regress grad150 i.control if research==1
regress grad150 i.controlcat if research==1
regress grad150 i.controlcat if research==1 & controlcat!=1

/* Among 4-year non-research colleges, do graduation rates vary by control (private/public, profit/non) */


*************************
* BASIC GRAPHS

* Stata has powerful graphical facilities. As a consequence the code for
* creating nice graphs can get complicated. 

* Here are two good graphics tutorials:
* http://data.princeton.edu/stata/graphics.html
* http://www.ssc.wisc.edu/sscc/pubs/4-24.htm

* Histograms, view the distribution of an interval variable: histogram
hist grad150
hist pell_value, frac normal /*notice the first graph has been replaced*/
hist student_count, freq //who's got 250k students?
list chronname student_count if student_count>100000

* To keep multiple graphs open: name them
hist lnaid, name(aid, replace)
hist pell_value, name(pell, replace)

* to have multiple graphs in tabs: set autotabgraphs on
*CHECK THIS, not clear it works in mac
set autotabgraphs on
hist lnaid, name(aid, replace)
hist pell_value, name(pell, replace)

* if you close graphs, they're not gone! They're in memory:
graph dir
graph display aid

* to drop graphs from memory
graph drop aid
graph drop _all /*drop everything*/

* Boxplots, compare the distribution of an interval variable across the categories of a categorical/ordered variable
graph box endow_value, over(control) /* 'over' segments the plot by the values of the listed variable */
* omit the empty category with the nofill option
graph box endow_value, over(control) nofill
* add condition (and log the outcome)
gen lnendow=ln(endow_value)
graph box lnendow if level=="4-year", over(control) nofill

* Scatterplot, view the relationship between two interval variables: graph twoway scatter
graph twoway scatter grad150 pell_value if level=="4-year" & control=="Public"
twoway scatter grad150 med_sat_value if level=="4-year" & control=="Public" /* You can omit the 'graph' */
scatter grad150 aid_value if level=="4-year" & control=="Public"  /* You can omit the 'twoway' */

/* Among 4-year research universities, do graduation rates vary by average student aid? */
twoway scatter grad150 lnaid if research==1 & controlcat!=1 

* Let's prettify!
* add linear regression line using lfit and smoothed locally weighted line using lowess
twoway scatter grad150 lnaid || lfit grad150 lnaid || lowess grad150 lnaid || if research==1 & controlcat!=1 
* (1) create better labeling on legend; (2) add graph title; (3) add x-axis and y-axis titles
twoway scatter grad150 lnaid || lfit grad150 lnaid || lowess grad150 lnaid || if research==1 & controlcat!=1, ///
   legend(order(2 3) label(2 "Regression Line") label(3 "Lowess Line")) title("Completion Rate by Student Aid") ///
   xtitle("Average Student Aid (logged)") ytitle("Completion within 150% of Expected Time")
* order(2 3) says keep 2nd and 3rd legend items; label(2 ... ) provides label for relevant item


/* Does the relationship look the same for public/private universities? */
twoway scatter grad150 lnaid if controlcat==2, msymbol(Oh) mcolor(green) || ///
	scatter grad150 lnaid if controlcat==3, msymbol(Oh) mcolor(blue) || ///
	lfit grad150 lnaid if controlcat==2, lcolor(green) || lfit grad150 lnaid if controlcat==3, lcolor(blue) || ///
	lowess grad150 lnaid if controlcat==2, lcolor(midgreen) || lowess grad150 lnaid if controlcat==3, lcolor(midblue) || ///
	if research==1, ytitle("Completion Rate") xtitle("Average Student Aid (logged)") ///
	title("6-Year Completion Rates by Average Student Aid") subtitle("Across 4-Year Research Universities") ///
	legend(label(1 "Private") label(2 "Public") label(3 "OLS Fit") label(4 "OLS Fit") label(5 "Lowess Curve") label(6 "Lowess Curve"))
	
/* Among 4-year research universities, do graduate rates vary by percent of students receiving Pell grants? */
\

*Close log
log close
